@@ -1,7 +1,7 @@
 /* ---------------------- mix_vm.h :
  * Types and functions implementing the MIX virtual machine
  * ------------------------------------------------------------------
- * Copyright (C) 2000 jose antonio ortega ruiz <jaortega@acm.org>
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 
 #include "mix_types.h"
 #include "mix_ins.h"
+#include "mix_device.h"
 #include "mix_code_file.h"
 #include "mix_src_file.h"
 #include "mix_symbol_table.h"
@@ -46,6 +47,10 @@ mix_vm_new(void);
 extern void
 mix_vm_delete(mix_vm_t * vm);
 
+/* connect devices to a virtual machine */
+extern mix_device_t * /* previously connected device */
+mix_vm_connect_device (mix_vm_t *vm, mix_device_t *device);
+
 /* Reset a vm (set state as of a newly created one) */
 extern void
 mix_vm_reset(mix_vm_t * vm);
@@ -128,6 +133,14 @@ mix_vm_get_symbol_table (const mix_vm_t *vm);
 extern mix_address_t 
 mix_vm_get_prog_count (const mix_vm_t *vm);
 
+/* Get the source line number for a given address */
+extern guint
+mix_vm_get_address_lineno (const mix_vm_t *vm, mix_address_t addr);
+
+/* Get the address for a given source line number */
+extern mix_address_t
+mix_vm_get_lineno_address (const mix_vm_t *vm, guint lineno);
+
 /* Reposition program counter and reset state so that a loaded
    program can be restarted.
 */
@@ -176,6 +189,9 @@ mix_vm_clear_breakpoint (mix_vm_t *vm, guint lineno);
 extern gint /* one of MIX_VM_BP_ */
 mix_vm_clear_breakpoint_address (mix_vm_t *vm, guint address) ;
 
+extern gboolean
+mix_vm_has_breakpoint_at_address (const mix_vm_t *vm, guint address);
+
 extern void
 mix_vm_clear_all_breakpoints (mix_vm_t *vm);
 
