@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mix_vm_command.c :
  * Implementation of the functions declared in mix_vm_command.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "01/03/15 15:57:52 jose"
+ *  Last change: Time-stamp: "01/04/01 15:16:18 jose"
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -859,8 +859,8 @@ static gboolean
 cmd_smem_ (mix_vm_cmd_dispatcher_t *dis, const gchar *carg)
 {
   gboolean ok = (strlen (carg) > 2 && isdigit (carg[0]));
-  gulong addr;
-  glong value;
+  glong addr = -1;
+  glong value = 0;
   int k = 0;
   gchar *arg = NULL;
   
@@ -893,7 +893,7 @@ cmd_smem_ (mix_vm_cmd_dispatcher_t *dis, const gchar *carg)
       fprintf (dis->err, _("Invalid argument: %s\n"), arg);
       cmd_help_ (dis, "smem");
     }
-  g_free (arg);
+  if (arg) g_free (arg);
   
   return ok;
 }
