@@ -23,7 +23,12 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <getopt.h>
+
+#ifdef HAVE_GETOPT_LONG
+#  include <getopt.h>
+#else
+#  include <lib/getopt.h>
+#endif /* HAVE_GETOPT_LONG */
 
 #include "mixasm_comp.h"
 
