@@ -20,7 +20,6 @@
  */
 
 
-#define _GNU_SOURCE 1
 #include <stdio.h>
 
 #include <mixlib/mix.h>
@@ -38,12 +37,10 @@
 static char *
 readline (char *prompt)
 {
-  char *line = NULL;
-  size_t s = 0;
-  
+  enum {LINE_LEN = 256};
+  char *line = g_new (char, LINE_LEN);
   printf ("%s", prompt);
-  getline (&line, &s, stdin);
-  return line;
+  return fgets (line, LINE_LEN, stdin);
 }
 #endif /* HAVE_LIBREADLINE */
 
